@@ -43,7 +43,7 @@ class Select(AbstractStatement, Sqlable):
     def table(self):
         if issubclass(self.select_from, Table):
             return self.select_from
-        elif issubclass(self.select_from, Select):
+        elif isinstance(self.select_from, Select):
             return self.select_from.table
         else:
             raise ValueError(f'unexpected {self.select_from=}')
